"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var getAuthDataFromRequest_exports = {};
__export(getAuthDataFromRequest_exports, {
  getAuthDataFromRequest: () => getAuthDataFromRequest
});
module.exports = __toCommonJS(getAuthDataFromRequest_exports);
var import_internal = require("@clerk/backend/internal");
var import_jwt = require("@clerk/backend/jwt");
var import_constants = require("../constants");
var import_headers_utils = require("../headers-utils");
var import_utils = require("../utils");
function getAuthDataFromRequest(req, {
  treatPendingAsSignedOut = true,
  ...opts
} = {}) {
  var _a, _b, _c;
  const authStatus = (0, import_headers_utils.getAuthKeyFromRequest)(req, "AuthStatus");
  const authToken = (0, import_headers_utils.getAuthKeyFromRequest)(req, "AuthToken");
  const authMessage = (0, import_headers_utils.getAuthKeyFromRequest)(req, "AuthMessage");
  const authReason = (0, import_headers_utils.getAuthKeyFromRequest)(req, "AuthReason");
  const authSignature = (0, import_headers_utils.getAuthKeyFromRequest)(req, "AuthSignature");
  (_a = opts.logger) == null ? void 0 : _a.debug("headers", { authStatus, authMessage, authReason });
  const encryptedRequestData = (0, import_headers_utils.getHeader)(req, import_internal.constants.Headers.ClerkRequestData);
  const decryptedRequestData = (0, import_utils.decryptClerkRequestData)(encryptedRequestData);
  const options = {
    secretKey: (opts == null ? void 0 : opts.secretKey) || decryptedRequestData.secretKey || import_constants.SECRET_KEY,
    publishableKey: decryptedRequestData.publishableKey || import_constants.PUBLISHABLE_KEY,
    apiUrl: import_constants.API_URL,
    apiVersion: import_constants.API_VERSION,
    authStatus,
    authMessage,
    authReason,
    treatPendingAsSignedOut
  };
  (_b = opts.logger) == null ? void 0 : _b.debug("auth options", options);
  let authObject;
  if (!authStatus || authStatus !== import_internal.AuthStatus.SignedIn) {
    authObject = (0, import_internal.signedOutAuthObject)(options);
  } else {
    (0, import_utils.assertTokenSignature)(authToken, options.secretKey, authSignature);
    const jwt = (0, import_jwt.decodeJwt)(authToken);
    (_c = opts.logger) == null ? void 0 : _c.debug("jwt", jwt.raw);
    authObject = (0, import_internal.signedInAuthObject)(options, jwt.raw.text, jwt.payload);
  }
  if (treatPendingAsSignedOut && authObject.sessionStatus === "pending") {
    authObject = (0, import_internal.signedOutAuthObject)(options, authObject.sessionStatus);
  }
  return authObject;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getAuthDataFromRequest
});
//# sourceMappingURL=getAuthDataFromRequest.js.map